-- Table: cil

-- DROP TABLE cil;

CREATE TABLE cil
(
  id bigint NOT NULL,
  nazev character varying NOT NULL,
  url character varying, -- Odkaz na daný cíl – pokud je to např. webová stránka
  selekt character varying NOT NULL, -- SQL dotaz, kterým získáme ze zdrojové databáze: IP adresu (sloupeček "ip"), počet pokusů (sloupeček "pocet") o spamování a den pokusu (sloupeček "den"). To vše pro období od do (dva parametry dotazu) včetně.
  databaze character varying NOT NULL, -- Celé JNDI jméno datového zdroje – databáze, na které bude volán selekt.
  CONSTRAINT cil_pk PRIMARY KEY (id)
)
WITH (OIDS=FALSE);
ALTER TABLE cil OWNER TO hrisnicispameri;
COMMENT ON TABLE cil IS 'Definice cílu (oběti) spamování.';
COMMENT ON COLUMN cil.url IS 'Odkaz na daný cíl – pokud je to např. webová stránka';
COMMENT ON COLUMN cil.selekt IS 'SQL dotaz, kterým získáme ze zdrojové databáze: IP adresu (sloupeček "ip"), počet pokusů (sloupeček "pocet") o spamování a den pokusu (sloupeček "den"). To vše pro období od do (dva parametry dotazu) včetně.';
COMMENT ON COLUMN cil.databaze IS 'Celé JNDI jméno datového zdroje – databáze, na které bude volán selekt.';


-- Table: souhrn

-- DROP TABLE souhrn;

CREATE TABLE souhrn
(
  den date NOT NULL,
  ip character varying NOT NULL, -- IP adresa hříšníka
  domena character varying, -- Doménové jméno hříšníka (překlad IP adresy)
  pocet bigint NOT NULL, -- Počet pokusů o spamování v daném dni
  cil bigint, -- Cíl útoku - spamování
  CONSTRAINT souhrn_pk PRIMARY KEY (den, ip),
  CONSTRAINT souhrn_cil_fk FOREIGN KEY (cil)
      REFERENCES cil (id) MATCH SIMPLE
      ON UPDATE NO ACTION ON DELETE NO ACTION,
  CONSTRAINT souhrn_pocet CHECK (pocet > 0)
)
WITH (OIDS=FALSE);
ALTER TABLE souhrn OWNER TO hrisnicispameri;
COMMENT ON TABLE souhrn IS 'Denní souhrny hříšníků, kteří se pokusili spamovat některý z webů (cílů).';
COMMENT ON COLUMN souhrn.ip IS 'IP adresa hříšníka';
COMMENT ON COLUMN souhrn.domena IS 'Doménové jméno hříšníka (překlad IP adresy)';
COMMENT ON COLUMN souhrn.pocet IS 'Počet pokusů o spamování v daném dni';
COMMENT ON COLUMN souhrn.cil IS 'Cíl útoku - spamování';


